import React from "react";
import cockpit from "cockpit";
import {
    Flex,
    FlexItem,
    Popover,
    Spinner,
    Switch,
    ToggleGroup,
    ToggleGroupItem
} from "@patternfly/react-core";
import { ErrorIcon } from "./app.components.jsx";
import { Button } from "@patternfly/react-core/dist/esm/components/Button";
import { OutlinedQuestionCircleIcon } from "@patternfly/react-icons";

const _ = cockpit.gettext;

export const RevPiSwitch = (props) => {
    const { id, isEnabled, isLoading } = props.item;

    return (
        <RevPiFlexBase {...props}>
            <Switch
                hasCheckIcon
                id={id}
                label={_("Enabled")}
                labelOff={_("Disabled")}
                isChecked={isEnabled}
                isDisabled={isLoading}
                onChange={() => {
                    props.switchHandler(id, isEnabled, isLoading);
                }}
            />
        </RevPiFlexBase>
    );
};

export const RevPiToggle = (props) => {
    const {
        id,
        isEnabled,
        isLoading,
        options = []
    } = props.item;

    const {
        enabled,
        disabled
    } = options;

    return (

        <RevPiFlexBase {...props}>
            <ToggleGroup>
                <>
                    <ToggleGroupItem
                        text={enabled.title}
                        isSelected={isEnabled === true}
                        onChange={() => props.switchHandler(id, false, isLoading)}
                    />
                    <ToggleGroupItem
                        text={disabled.title}
                        isSelected={isEnabled === false}
                        onChange={() => props.switchHandler(id, true, isLoading)}
                    />
                </>
            </ToggleGroup>
        </RevPiFlexBase>

    );
};

export function RevPiFlexBase (props) {
    const {
        title,
        helpText,
        hasError,
        isAvailable,
        isLoading,
        rebootRequired
    } = props.item;

    if (isAvailable === false) {
        return <></>;
    }

    return (
        <Flex
            style={{ minHeight: "2lh" }}
            direction={{ default: "row" }}
            alignItems={{ default: "alignItemsCenter" }}
        >

            <FlexItem grow={{ default: "grow" }}>
                <Flex direction={{ default: "row" }}>
                    <Flex direction={{ default: "column" }} gap={{ default: "gapNone" }}>
                        <FlexItem>{title}</FlexItem>
                        {rebootRequired && <FlexItem className='card-title-label'>{_("reboot required")}</FlexItem>}
                    </Flex>
                    {helpText &&
                    <Flex>
                        <RevPiHelpText title={title}>
                            {helpText}
                        </RevPiHelpText>
                    </Flex>}
                </Flex>
            </FlexItem>

            <FlexItem>
                {isLoading && <Spinner size='lg' />}
                {hasError && !isLoading && <ErrorIcon />}
            </FlexItem>

            <FlexItem>
                {props.children}
            </FlexItem>

        </Flex>
    );
}

export function RevPiHelpText ({
    title,
    children,
    footer
}) {
    return (
        <Popover
            headerContent={<div>{title}</div>}
            bodyContent={<div>{children}</div>}
            footerContent={<div>{footer}</div>}
        >
            <Button variant='link' icon={<OutlinedQuestionCircleIcon />} />
        </Popover>
    );
}
